[![Git](https://git-scm.com/images/logo@2x.png)](https://git-scm.com/) --fast-version-control
![](https://git-scm.com/images/dark-mode.svg)
  * [About](https://git-scm.com/about)
    * [Trademark](https://git-scm.com/about/trademark)
  * [Learn](https://git-scm.com/learn)
    * [Book](https://git-scm.com/book)
    * [Cheat Sheet](https://git-scm.com/cheat-sheet)
    * [Videos](https://git-scm.com/videos)
    * [External Links](https://git-scm.com/doc/ext)
  * [Tools](https://git-scm.com/tools)
    * [Command Line](https://git-scm.com/tools/command-line)
    * [GUIs](https://git-scm.com/tools/guis)
    * [Hosting](https://git-scm.com/tools/hosting)
  * [Reference](https://git-scm.com/docs)
  * [Install](https://git-scm.com/install/linux)
  * [Community](https://git-scm.com/community)


  * Table of Contents
    * [NAME](https://git-scm.com/docs/git-submodule#_name)
    * [SYNOPSIS](https://git-scm.com/docs/git-submodule#_synopsis)
    * [DESCRIPTION](https://git-scm.com/docs/git-submodule#_description)
    * [COMMANDS](https://git-scm.com/docs/git-submodule#_commands)
    * [OPTIONS](https://git-scm.com/docs/git-submodule#_options)
    * [FILES](https://git-scm.com/docs/git-submodule#_files)
    * [SEE ALSO](https://git-scm.com/docs/git-submodule#_see_also)
    * [GIT](https://git-scm.com/docs/git-submodule#_git)


[ English ▾](https://git-scm.com/docs/git-submodule)
Localized versions of **git-submodule** manual
  1. [English ](https://git-scm.com/docs/git-submodule)
  2. [Français ](https://git-scm.com/docs/git-submodule/fr)
  3. [Português (Brasil) ](https://git-scm.com/docs/git-submodule/pt_BR)
  4. [Svenska ](https://git-scm.com/docs/git-submodule/sv)
  5. [українська мова ](https://git-scm.com/docs/git-submodule/uk)
  6. [简体中文 ](https://git-scm.com/docs/git-submodule/zh_HANS-CN)

Want to read in your language or fix typos?
[You can help translate this page](https://github.com/jnavila/git-manpages-l10n).
[Topics ▾](https://git-scm.com/docs/git-submodule)
### Setup and Config
  * [ git ](https://git-scm.com/docs/git)
  * [ config ](https://git-scm.com/docs/git-config)
  * [ help ](https://git-scm.com/docs/git-help)
  * [ bugreport ](https://git-scm.com/docs/git-bugreport)
  * [ Credential helpers ](https://git-scm.com/doc/credential-helpers)


### Getting and Creating Projects
  * [ init ](https://git-scm.com/docs/git-init)
  * [ clone ](https://git-scm.com/docs/git-clone)


### Basic Snapshotting
  * [ add ](https://git-scm.com/docs/git-add)
  * [ status ](https://git-scm.com/docs/git-status)
  * [ diff ](https://git-scm.com/docs/git-diff)
  * [ commit ](https://git-scm.com/docs/git-commit)
  * [ notes ](https://git-scm.com/docs/git-notes)
  * [ restore ](https://git-scm.com/docs/git-restore)
  * [ reset ](https://git-scm.com/docs/git-reset)
  * [ rm ](https://git-scm.com/docs/git-rm)
  * [ mv ](https://git-scm.com/docs/git-mv)


### Branching and Merging
  * [ branch ](https://git-scm.com/docs/git-branch)
  * [ checkout ](https://git-scm.com/docs/git-checkout)
  * [ switch ](https://git-scm.com/docs/git-switch)
  * [ merge ](https://git-scm.com/docs/git-merge)
  * [ mergetool ](https://git-scm.com/docs/git-mergetool)
  * [ log ](https://git-scm.com/docs/git-log)
  * [ stash ](https://git-scm.com/docs/git-stash)
  * [ tag ](https://git-scm.com/docs/git-tag)
  * [ worktree ](https://git-scm.com/docs/git-worktree)


### Sharing and Updating Projects
  * [ fetch ](https://git-scm.com/docs/git-fetch)
  * [ pull ](https://git-scm.com/docs/git-pull)
  * [ push ](https://git-scm.com/docs/git-push)
  * [ remote ](https://git-scm.com/docs/git-remote)
  * [ submodule ](https://git-scm.com/docs/git-submodule)


### Inspection and Comparison
  * [ show ](https://git-scm.com/docs/git-show)
  * [ log ](https://git-scm.com/docs/git-log)
  * [ diff ](https://git-scm.com/docs/git-diff)
  * [ difftool ](https://git-scm.com/docs/git-difftool)
  * [ range-diff ](https://git-scm.com/docs/git-range-diff)
  * [ shortlog ](https://git-scm.com/docs/git-shortlog)
  * [ describe ](https://git-scm.com/docs/git-describe)


### Patching
  * [ apply ](https://git-scm.com/docs/git-apply)
  * [ cherry-pick ](https://git-scm.com/docs/git-cherry-pick)
  * [ diff ](https://git-scm.com/docs/git-diff)
  * [ rebase ](https://git-scm.com/docs/git-rebase)
  * [ revert ](https://git-scm.com/docs/git-revert)


### Debugging
  * [ bisect ](https://git-scm.com/docs/git-bisect)
  * [ blame ](https://git-scm.com/docs/git-blame)
  * [ grep ](https://git-scm.com/docs/git-grep)


### Email
  * [ am ](https://git-scm.com/docs/git-am)
  * [ apply ](https://git-scm.com/docs/git-apply)
  * [ imap-send ](https://git-scm.com/docs/git-imap-send)
  * [ format-patch ](https://git-scm.com/docs/git-format-patch)
  * [ send-email ](https://git-scm.com/docs/git-send-email)
  * [ request-pull ](https://git-scm.com/docs/git-request-pull)


### External Systems
  * [ svn ](https://git-scm.com/docs/git-svn)
  * [ fast-import ](https://git-scm.com/docs/git-fast-import)


### Server Admin
  * [ daemon ](https://git-scm.com/docs/git-daemon)
  * [ update-server-info ](https://git-scm.com/docs/git-update-server-info)


### Guides
  * [ gitattributes ](https://git-scm.com/docs/gitattributes)
  * [ Command-line interface conventions ](https://git-scm.com/docs/gitcli)
  * [ Everyday Git ](https://git-scm.com/docs/giteveryday)
  * [ Frequently Asked Questions (FAQ) ](https://git-scm.com/docs/gitfaq)
  * [ Glossary ](https://git-scm.com/docs/gitglossary)
  * [ Hooks ](https://git-scm.com/docs/githooks)
  * [ gitignore ](https://git-scm.com/docs/gitignore)
  * [ gitmodules ](https://git-scm.com/docs/gitmodules)
  * [ Revisions ](https://git-scm.com/docs/gitrevisions)
  * [ Submodules ](https://git-scm.com/docs/gitsubmodules)
  * [ Tutorial ](https://git-scm.com/docs/gittutorial)
  * [ Workflows ](https://git-scm.com/docs/gitworkflows)
  * [ All guides... ](https://git-scm.com/docs/git#_guides)


### Administration
  * [ clean ](https://git-scm.com/docs/git-clean)
  * [ gc ](https://git-scm.com/docs/git-gc)
  * [ fsck ](https://git-scm.com/docs/git-fsck)
  * [ reflog ](https://git-scm.com/docs/git-reflog)
  * [ filter-branch ](https://git-scm.com/docs/git-filter-branch)
  * [ instaweb ](https://git-scm.com/docs/git-instaweb)
  * [ archive ](https://git-scm.com/docs/git-archive)
  * [ bundle ](https://git-scm.com/docs/git-bundle)


### Plumbing Commands
  * [ cat-file ](https://git-scm.com/docs/git-cat-file)
  * [ check-ignore ](https://git-scm.com/docs/git-check-ignore)
  * [ checkout-index ](https://git-scm.com/docs/git-checkout-index)
  * [ commit-tree ](https://git-scm.com/docs/git-commit-tree)
  * [ count-objects ](https://git-scm.com/docs/git-count-objects)
  * [ diff-index ](https://git-scm.com/docs/git-diff-index)
  * [ for-each-ref ](https://git-scm.com/docs/git-for-each-ref)
  * [ hash-object ](https://git-scm.com/docs/git-hash-object)
  * [ ls-files ](https://git-scm.com/docs/git-ls-files)
  * [ ls-tree ](https://git-scm.com/docs/git-ls-tree)
  * [ merge-base ](https://git-scm.com/docs/git-merge-base)
  * [ read-tree ](https://git-scm.com/docs/git-read-tree)
  * [ rev-list ](https://git-scm.com/docs/git-rev-list)
  * [ rev-parse ](https://git-scm.com/docs/git-rev-parse)
  * [ show-ref ](https://git-scm.com/docs/git-show-ref)
  * [ symbolic-ref ](https://git-scm.com/docs/git-symbolic-ref)
  * [ update-index ](https://git-scm.com/docs/git-update-index)
  * [ update-ref ](https://git-scm.com/docs/git-update-ref)
  * [ verify-pack ](https://git-scm.com/docs/git-verify-pack)
  * [ write-tree ](https://git-scm.com/docs/git-write-tree)


[ Latest version ▾ ](https://git-scm.com/docs/git-submodule) git-submodule last updated in 2.52.0
Changes in the **git-submodule** manual
  1. 2.53.0 no changes
  2. [2.52.0 ![](https://git-scm.com/images/icons/green-dot.png) ![](https://git-scm.com/images/icons/green-dot.png) ![](https://git-scm.com/images/icons/green-dot.png) ![](https://git-scm.com/images/icons/green-dot.png) ![](https://git-scm.com/images/icons/red-dot.png) ![](https://git-scm.com/images/icons/red-dot.png) ![](https://git-scm.com/images/icons/grey-dot.png) ![](https://git-scm.com/images/icons/grey-dot.png) _2025-11-17_ ](https://git-scm.com/docs/git-submodule/2.52.0)
  3. 2.51.1 → 2.51.2 no changes
  4. [2.51.0 ![](https://git-scm.com/images/icons/green-dot.png) ![](https://git-scm.com/images/icons/green-dot.png) ![](https://git-scm.com/images/icons/green-dot.png) ![](https://git-scm.com/images/icons/green-dot.png) ![](https://git-scm.com/images/icons/green-dot.png) ![](https://git-scm.com/images/icons/green-dot.png) ![](https://git-scm.com/images/icons/green-dot.png) ![](https://git-scm.com/images/icons/red-dot.png) ![](https://git-scm.com/images/icons/red-dot.png) ![](https://git-scm.com/images/icons/grey-dot.png) _2025-08-18_ ](https://git-scm.com/docs/git-submodule/2.51.0)
  5. 2.47.1 → 2.50.1 no changes
  6. [2.47.0 ![](https://git-scm.com/images/icons/green-dot.png) ![](https://git-scm.com/images/icons/green-dot.png) ![](https://git-scm.com/images/icons/green-dot.png) ![](https://git-scm.com/images/icons/green-dot.png) ![](https://git-scm.com/images/icons/green-dot.png) ![](https://git-scm.com/images/icons/green-dot.png) ![](https://git-scm.com/images/icons/red-dot.png) ![](https://git-scm.com/images/icons/red-dot.png) ![](https://git-scm.com/images/icons/grey-dot.png) ![](https://git-scm.com/images/icons/grey-dot.png) _2024-10-06_ ](https://git-scm.com/docs/git-submodule/2.47.0)
  7. 2.44.1 → 2.46.4 no changes
  8. [2.44.0 ![](https://git-scm.com/images/icons/green-dot.png) ![](https://git-scm.com/images/icons/green-dot.png) ![](https://git-scm.com/images/icons/red-dot.png) ![](https://git-scm.com/images/icons/red-dot.png) ![](https://git-scm.com/images/icons/grey-dot.png) ![](https://git-scm.com/images/icons/grey-dot.png) ![](https://git-scm.com/images/icons/grey-dot.png) ![](https://git-scm.com/images/icons/grey-dot.png) _2024-02-23_ ](https://git-scm.com/docs/git-submodule/2.44.0)
  9. 2.42.1 → 2.43.7 no changes
  10. [2.42.0 ![](https://git-scm.com/images/icons/green-dot.png) ![](https://git-scm.com/images/icons/green-dot.png) ![](https://git-scm.com/images/icons/green-dot.png) ![](https://git-scm.com/images/icons/green-dot.png) ![](https://git-scm.com/images/icons/green-dot.png) ![](https://git-scm.com/images/icons/red-dot.png) ![](https://git-scm.com/images/icons/red-dot.png) ![](https://git-scm.com/images/icons/red-dot.png) ![](https://git-scm.com/images/icons/grey-dot.png) ![](https://git-scm.com/images/icons/grey-dot.png) _2023-08-21_ ](https://git-scm.com/docs/git-submodule/2.42.0)
  11. 2.36.1 → 2.41.3 no changes
  12. [2.36.0 ![](https://git-scm.com/images/icons/green-dot.png) ![](https://git-scm.com/images/icons/green-dot.png) ![](https://git-scm.com/images/icons/green-dot.png) ![](https://git-scm.com/images/icons/green-dot.png) ![](https://git-scm.com/images/icons/green-dot.png) ![](https://git-scm.com/images/icons/red-dot.png) ![](https://git-scm.com/images/icons/grey-dot.png) ![](https://git-scm.com/images/icons/grey-dot.png) _2022-04-18_ ](https://git-scm.com/docs/git-submodule/2.36.0)
  13. 2.28.1 → 2.35.8 no changes
  14. [2.28.0 ![](https://git-scm.com/images/icons/green-dot.png) ![](https://git-scm.com/images/icons/green-dot.png) ![](https://git-scm.com/images/icons/green-dot.png) ![](https://git-scm.com/images/icons/green-dot.png) ![](https://git-scm.com/images/icons/red-dot.png) ![](https://git-scm.com/images/icons/red-dot.png) ![](https://git-scm.com/images/icons/red-dot.png) ![](https://git-scm.com/images/icons/red-dot.png) ![](https://git-scm.com/images/icons/grey-dot.png) ![](https://git-scm.com/images/icons/grey-dot.png) _2020-07-27_ ](https://git-scm.com/docs/git-submodule/2.28.0)
  15. 2.26.1 → 2.27.1 no changes
  16. [2.26.0 ![](https://git-scm.com/images/icons/green-dot.png) ![](https://git-scm.com/images/icons/green-dot.png) ![](https://git-scm.com/images/icons/green-dot.png) ![](https://git-scm.com/images/icons/green-dot.png) ![](https://git-scm.com/images/icons/green-dot.png) ![](https://git-scm.com/images/icons/red-dot.png) ![](https://git-scm.com/images/icons/grey-dot.png) ![](https://git-scm.com/images/icons/grey-dot.png) _2020-03-22_ ](https://git-scm.com/docs/git-submodule/2.26.0)
  17. 2.25.2 → 2.25.5 no changes
  18. [2.25.1 ![](https://git-scm.com/images/icons/green-dot.png) ![](https://git-scm.com/images/icons/red-dot.png) ![](https://git-scm.com/images/icons/grey-dot.png) ![](https://git-scm.com/images/icons/grey-dot.png) ![](https://git-scm.com/images/icons/grey-dot.png) ![](https://git-scm.com/images/icons/grey-dot.png) ![](https://git-scm.com/images/icons/grey-dot.png) ![](https://git-scm.com/images/icons/grey-dot.png) _2020-02-17_ ](https://git-scm.com/docs/git-submodule/2.25.1)
  19. [2.25.0 ![](https://git-scm.com/images/icons/green-dot.png) ![](https://git-scm.com/images/icons/green-dot.png) ![](https://git-scm.com/images/icons/green-dot.png) ![](https://git-scm.com/images/icons/green-dot.png) ![](https://git-scm.com/images/icons/green-dot.png) ![](https://git-scm.com/images/icons/green-dot.png) ![](https://git-scm.com/images/icons/green-dot.png) ![](https://git-scm.com/images/icons/red-dot.png) ![](https://git-scm.com/images/icons/grey-dot.png) ![](https://git-scm.com/images/icons/grey-dot.png) _2020-01-13_ ](https://git-scm.com/docs/git-submodule/2.25.0)
  20. 2.24.1 → 2.24.4 no changes
  21. [2.24.0 ![](https://git-scm.com/images/icons/green-dot.png) ![](https://git-scm.com/images/icons/green-dot.png) ![](https://git-scm.com/images/icons/red-dot.png) ![](https://git-scm.com/images/icons/grey-dot.png) ![](https://git-scm.com/images/icons/grey-dot.png) ![](https://git-scm.com/images/icons/grey-dot.png) ![](https://git-scm.com/images/icons/grey-dot.png) ![](https://git-scm.com/images/icons/grey-dot.png) _2019-11-04_ ](https://git-scm.com/docs/git-submodule/2.24.0)
  22. 2.22.1 → 2.23.4 no changes
  23. [2.22.0 ![](https://git-scm.com/images/icons/green-dot.png) ![](https://git-scm.com/images/icons/green-dot.png) ![](https://git-scm.com/images/icons/green-dot.png) ![](https://git-scm.com/images/icons/green-dot.png) ![](https://git-scm.com/images/icons/green-dot.png) ![](https://git-scm.com/images/icons/green-dot.png) ![](https://git-scm.com/images/icons/red-dot.png) ![](https://git-scm.com/images/icons/red-dot.png) ![](https://git-scm.com/images/icons/grey-dot.png) ![](https://git-scm.com/images/icons/grey-dot.png) _2019-06-07_ ](https://git-scm.com/docs/git-submodule/2.22.0)
  24. 2.19.1 → 2.21.4 no changes
  25. [2.19.0 ![](https://git-scm.com/images/icons/green-dot.png) ![](https://git-scm.com/images/icons/green-dot.png) ![](https://git-scm.com/images/icons/green-dot.png) ![](https://git-scm.com/images/icons/green-dot.png) ![](https://git-scm.com/images/icons/green-dot.png) ![](https://git-scm.com/images/icons/red-dot.png) ![](https://git-scm.com/images/icons/red-dot.png) ![](https://git-scm.com/images/icons/red-dot.png) ![](https://git-scm.com/images/icons/grey-dot.png) ![](https://git-scm.com/images/icons/grey-dot.png) _2018-09-10_ ](https://git-scm.com/docs/git-submodule/2.19.0)
  26. 2.18.1 → 2.18.5 no changes
  27. [2.18.0 ![](https://git-scm.com/images/icons/green-dot.png) ![](https://git-scm.com/images/icons/green-dot.png) ![](https://git-scm.com/images/icons/green-dot.png) ![](https://git-scm.com/images/icons/green-dot.png) ![](https://git-scm.com/images/icons/green-dot.png) ![](https://git-scm.com/images/icons/green-dot.png) ![](https://git-scm.com/images/icons/red-dot.png) ![](https://git-scm.com/images/icons/red-dot.png) ![](https://git-scm.com/images/icons/grey-dot.png) ![](https://git-scm.com/images/icons/grey-dot.png) _2018-06-21_ ](https://git-scm.com/docs/git-submodule/2.18.0)
  28. 2.17.0 → 2.17.6 no changes
  29. [2.16.6 ![](https://git-scm.com/images/icons/green-dot.png) ![](https://git-scm.com/images/icons/green-dot.png) ![](https://git-scm.com/images/icons/green-dot.png) ![](https://git-scm.com/images/icons/green-dot.png) ![](https://git-scm.com/images/icons/red-dot.png) ![](https://git-scm.com/images/icons/red-dot.png) ![](https://git-scm.com/images/icons/red-dot.png) ![](https://git-scm.com/images/icons/red-dot.png) ![](https://git-scm.com/images/icons/grey-dot.png) ![](https://git-scm.com/images/icons/grey-dot.png) _2019-12-06_ ](https://git-scm.com/docs/git-submodule/2.16.6)
  30. 2.15.4 no changes
  31. [2.14.6 ![](https://git-scm.com/images/icons/green-dot.png) ![](https://git-scm.com/images/icons/green-dot.png) ![](https://git-scm.com/images/icons/green-dot.png) ![](https://git-scm.com/images/icons/red-dot.png) ![](https://git-scm.com/images/icons/red-dot.png) ![](https://git-scm.com/images/icons/red-dot.png) ![](https://git-scm.com/images/icons/red-dot.png) ![](https://git-scm.com/images/icons/red-dot.png) ![](https://git-scm.com/images/icons/grey-dot.png) ![](https://git-scm.com/images/icons/grey-dot.png) _2019-12-06_ ](https://git-scm.com/docs/git-submodule/2.14.6)
  32. [2.13.7 ![](https://git-scm.com/images/icons/green-dot.png) ![](https://git-scm.com/images/icons/green-dot.png) ![](https://git-scm.com/images/icons/green-dot.png) ![](https://git-scm.com/images/icons/green-dot.png) ![](https://git-scm.com/images/icons/green-dot.png) ![](https://git-scm.com/images/icons/red-dot.png) ![](https://git-scm.com/images/icons/red-dot.png) ![](https://git-scm.com/images/icons/red-dot.png) ![](https://git-scm.com/images/icons/grey-dot.png) ![](https://git-scm.com/images/icons/grey-dot.png) _2018-05-22_ ](https://git-scm.com/docs/git-submodule/2.13.7)
  33. [2.12.5 ![](https://git-scm.com/images/icons/green-dot.png) ![](https://git-scm.com/images/icons/green-dot.png) ![](https://git-scm.com/images/icons/green-dot.png) ![](https://git-scm.com/images/icons/green-dot.png) ![](https://git-scm.com/images/icons/green-dot.png) ![](https://git-scm.com/images/icons/red-dot.png) ![](https://git-scm.com/images/icons/red-dot.png) ![](https://git-scm.com/images/icons/red-dot.png) ![](https://git-scm.com/images/icons/grey-dot.png) ![](https://git-scm.com/images/icons/grey-dot.png) _2017-09-22_ ](https://git-scm.com/docs/git-submodule/2.12.5)
  34. 2.11.4 no changes
  35. [2.10.5 ![](https://git-scm.com/images/icons/green-dot.png) ![](https://git-scm.com/images/icons/green-dot.png) ![](https://git-scm.com/images/icons/green-dot.png) ![](https://git-scm.com/images/icons/green-dot.png) ![](https://git-scm.com/images/icons/green-dot.png) ![](https://git-scm.com/images/icons/green-dot.png) ![](https://git-scm.com/images/icons/red-dot.png) ![](https://git-scm.com/images/icons/red-dot.png) ![](https://git-scm.com/images/icons/grey-dot.png) ![](https://git-scm.com/images/icons/grey-dot.png) _2017-09-22_ ](https://git-scm.com/docs/git-submodule/2.10.5)
  36. [2.9.5 ![](https://git-scm.com/images/icons/green-dot.png) ![](https://git-scm.com/images/icons/green-dot.png) ![](https://git-scm.com/images/icons/green-dot.png) ![](https://git-scm.com/images/icons/green-dot.png) ![](https://git-scm.com/images/icons/green-dot.png) ![](https://git-scm.com/images/icons/green-dot.png) ![](https://git-scm.com/images/icons/red-dot.png) ![](https://git-scm.com/images/icons/grey-dot.png) _2017-07-30_ ](https://git-scm.com/docs/git-submodule/2.9.5)
  37. [2.8.6 ![](https://git-scm.com/images/icons/green-dot.png) ![](https://git-scm.com/images/icons/green-dot.png) ![](https://git-scm.com/images/icons/green-dot.png) ![](https://git-scm.com/images/icons/green-dot.png) ![](https://git-scm.com/images/icons/green-dot.png) ![](https://git-scm.com/images/icons/red-dot.png) ![](https://git-scm.com/images/icons/red-dot.png) ![](https://git-scm.com/images/icons/red-dot.png) ![](https://git-scm.com/images/icons/grey-dot.png) ![](https://git-scm.com/images/icons/grey-dot.png) _2017-07-30_ ](https://git-scm.com/docs/git-submodule/2.8.6)
  38. 2.7.6 no changes
  39. [2.6.7 ![](https://git-scm.com/images/icons/green-dot.png) ![](https://git-scm.com/images/icons/green-dot.png) ![](https://git-scm.com/images/icons/green-dot.png) ![](https://git-scm.com/images/icons/green-dot.png) ![](https://git-scm.com/images/icons/red-dot.png) ![](https://git-scm.com/images/icons/grey-dot.png) ![](https://git-scm.com/images/icons/grey-dot.png) ![](https://git-scm.com/images/icons/grey-dot.png) _2017-05-05_ ](https://git-scm.com/docs/git-submodule/2.6.7)
  40. 2.5.6 no changes
  41. [2.4.12 ![](https://git-scm.com/images/icons/green-dot.png) ![](https://git-scm.com/images/icons/green-dot.png) ![](https://git-scm.com/images/icons/green-dot.png) ![](https://git-scm.com/images/icons/green-dot.png) ![](https://git-scm.com/images/icons/red-dot.png) ![](https://git-scm.com/images/icons/red-dot.png) ![](https://git-scm.com/images/icons/red-dot.png) ![](https://git-scm.com/images/icons/red-dot.png) ![](https://git-scm.com/images/icons/grey-dot.png) ![](https://git-scm.com/images/icons/grey-dot.png) _2017-05-05_ ](https://git-scm.com/docs/git-submodule/2.4.12)
  42. [2.3.10 ![](https://git-scm.com/images/icons/green-dot.png) ![](https://git-scm.com/images/icons/green-dot.png) ![](https://git-scm.com/images/icons/green-dot.png) ![](https://git-scm.com/images/icons/green-dot.png) ![](https://git-scm.com/images/icons/green-dot.png) ![](https://git-scm.com/images/icons/green-dot.png) ![](https://git-scm.com/images/icons/red-dot.png) ![](https://git-scm.com/images/icons/red-dot.png) ![](https://git-scm.com/images/icons/grey-dot.png) ![](https://git-scm.com/images/icons/grey-dot.png) _2015-09-28_ ](https://git-scm.com/docs/git-submodule/2.3.10)
  43. 2.1.4 → 2.2.3 no changes
  44. [2.0.5 ![](https://git-scm.com/images/icons/green-dot.png) ![](https://git-scm.com/images/icons/green-dot.png) ![](https://git-scm.com/images/icons/green-dot.png) ![](https://git-scm.com/images/icons/green-dot.png) ![](https://git-scm.com/images/icons/green-dot.png) ![](https://git-scm.com/images/icons/green-dot.png) ![](https://git-scm.com/images/icons/green-dot.png) ![](https://git-scm.com/images/icons/green-dot.png) ![](https://git-scm.com/images/icons/red-dot.png) ![](https://git-scm.com/images/icons/red-dot.png) ![](https://git-scm.com/images/icons/grey-dot.png) ![](https://git-scm.com/images/icons/grey-dot.png) _2014-12-17_ ](https://git-scm.com/docs/git-submodule/2.0.5)


Check your version of git by running
`git --version`
##  [](https://git-scm.com/docs/git-submodule#_name)NAME
git-submodule - Initialize, update or inspect submodules
##  [](https://git-scm.com/docs/git-submodule#_synopsis)SYNOPSIS
```
_git submodule_ [--quiet] [--cached]
_git submodule_ [--quiet] add [<options>] [--] <repository> [<path>]
_git submodule_ [--quiet] status [--cached] [--recursive] [--] [<path>…​]
_git submodule_ [--quiet] init [--] [<path>…​]
_git submodule_ [--quiet] deinit [-f|--force] (--all|[--] <path>…​)
_git submodule_ [--quiet] update [<options>] [--] [<path>…​]
_git submodule_ [--quiet] set-branch [<options>] [--] <path>
_git submodule_ [--quiet] set-url [--] <path> <newurl>
_git submodule_ [--quiet] summary [<options>] [--] [<path>…​]
_git submodule_ [--quiet] foreach [--recursive] <command>
_git submodule_ [--quiet] sync [--recursive] [--] [<path>…​]
_git submodule_ [--quiet] absorbgitdirs [--] [<path>…​]
```

##  [](https://git-scm.com/docs/git-submodule#_description)DESCRIPTION
Inspects, updates and manages submodules.
For more information about submodules, see [gitsubmodules[7]](https://git-scm.com/docs/gitsubmodules).
##  [](https://git-scm.com/docs/git-submodule#_commands)COMMANDS
With no arguments, shows the status of existing submodules. Several subcommands are available to perform operations on the submodules.

[](https://git-scm.com/docs/git-submodule#Documentation/git-submodule.txt-add-bbranch-f--force--namename--referencerepository--ref-formatformat--depthdepth--repositorypath)add [-b <branch>] [-f|--force] [--name <name>] [--reference <repository>] [--ref-format <format>] [--depth <depth>] [--] <repository> [<path>]

Add the given repository as a submodule at the given path to the changeset to be committed next to the current project: the current project is termed the "superproject".
<repository> is the URL of the new submodule’s origin repository. This may be either an absolute URL, or (if it begins with ./ or ../), the location relative to the superproject’s default remote repository (Please note that to specify a repository _foo.git_ which is located right next to a superproject _bar.git_ , you’ll have to use `../foo.git` instead of `./foo.git` - as one might expect when following the rules for relative URLs - because the evaluation of relative URLs in Git is identical to that of relative directories).
The default remote is the remote of the remote-tracking branch of the current branch. If no such remote-tracking branch exists or the HEAD is detached, "origin" is assumed to be the default remote. If the superproject doesn’t have a default remote configured the superproject is its own authoritative upstream and the current working directory is used instead.
The optional argument <path> is the relative location for the cloned submodule to exist in the superproject. If <path> is not given, the canonical part of the source repository is used ("repo" for "/path/to/repo.git" and "foo" for "host.xz:foo/.git"). If <path> exists and is already a valid Git repository, then it is staged for commit without cloning. The <path> is also used as the submodule’s logical name in its configuration entries unless `--name` is used to specify a logical name.
The given URL is recorded into `.gitmodules` for use by subsequent users cloning the superproject. If the URL is given relative to the superproject’s repository, the presumption is the superproject and submodule repositories will be kept together in the same relative location, and only the superproject’s URL needs to be provided. git-submodule will correctly locate the submodule using the relative URL in `.gitmodules`.
If `--ref-format` _< format>_ is specified, the ref storage format of newly cloned submodules will be set accordingly.

[](https://git-scm.com/docs/git-submodule#Documentation/git-submodule.txt-status--cached--recursive--path)status [--cached] [--recursive] [--] [<path>…​]

Show the status of the submodules. This will print the SHA-1 of the currently checked out commit for each submodule, along with the submodule path and the output of _git describe_ for the SHA-1. Each SHA-1 will possibly be prefixed with `-` if the submodule is not initialized, `+` if the currently checked out submodule commit does not match the SHA-1 found in the index of the containing repository and `U` if the submodule has merge conflicts.
If `--cached` is specified, this command will instead print the SHA-1 recorded in the superproject for each submodule.
If `--recursive` is specified, this command will recurse into nested submodules, and show their status as well.
If you are only interested in changes of the currently initialized submodules with respect to the commit recorded in the index or the HEAD, [git-status[1]](https://git-scm.com/docs/git-status) and [git-diff[1]](https://git-scm.com/docs/git-diff) will provide that information too (and can also report changes to a submodule’s work tree).

[](https://git-scm.com/docs/git-submodule#Documentation/git-submodule.txt-init--path)init [--] [<path>…​]

Initialize the submodules recorded in the index (which were added and committed elsewhere) by setting `submodule.$name.url` in `.git/config`, using the same setting from `.gitmodules` as a template. If the URL is relative, it will be resolved using the default remote. If there is no default remote, the current repository will be assumed to be upstream.
Optional <path> arguments limit which submodules will be initialized. If no path is specified and submodule.active has been configured, submodules configured to be active will be initialized, otherwise all submodules are initialized.
It will also copy the value of `submodule.$name.update`, if present in the `.gitmodules` file, to `.git/config`, but (1) this command does not alter existing information in `.git/config`, and (2) `submodule.$name.update` that is set to a custom command is **not** copied for security reasons.
You can then customize the submodule clone URLs in `.git/config` for your local setup and proceed to `git` `submodule` `update`; you can also just use `git` `submodule` `update` `--init` without the explicit _init_ step if you do not intend to customize any submodule locations.
See the add subcommand for the definition of default remote.

[](https://git-scm.com/docs/git-submodule#Documentation/git-submodule.txt-deinit-f--force--all--path)deinit [-f|--force] (--all|[--] <path>…​)

Unregister the given submodules, i.e. remove the whole `submodule.$name` section from .git/config together with their work tree. Further calls to `git` `submodule` `update`, `git` `submodule` `foreach` and `git` `submodule` `sync` will skip any unregistered submodules until they are initialized again, so use this command if you don’t want to have a local checkout of the submodule in your working tree anymore.
When the command is run without pathspec, it errors out, instead of deinit-ing everything, to prevent mistakes.
If `--force` is specified, the submodule’s working tree will be removed even if it contains local modifications.
If you really want to remove a submodule from the repository and commit that use [git-rm[1]](https://git-scm.com/docs/git-rm) instead. See [gitsubmodules[7]](https://git-scm.com/docs/gitsubmodules) for removal options.

[](https://git-scm.com/docs/git-submodule#Documentation/git-submodule.txt-update--init--remote-N--no-fetch--no-recommend-shallow-f--force--checkout--rebase--merge--referencerepository--ref-formatformat--depthdepth--recursive--jobsn--no-single-branch--filterfilter-spec--path)update [--init] [--remote] [-N|--no-fetch] [--[no-]recommend-shallow] [-f|--force] [--checkout|--rebase|--merge] [--reference <repository>] [--ref-format <format>] [--depth <depth>] [--recursive] [--jobs <n>] [--[no-]single-branch] [--filter <filter-spec>] [--] [<path>…​]

Update the registered submodules to match what the superproject expects by cloning missing submodules, fetching missing commits in submodules and updating the working tree of the submodules. The "updating" can be done in several ways depending on command line options and the value of `submodule.`_< name>_`.update` configuration variable. The command line option takes precedence over the configuration variable. If neither is given, a _checkout_ is performed. (note: what is in `.gitmodules` file is irrelevant at this point; see `git` `submodule` `init` above for how `.gitmodules` is used). The _update_ procedures supported both from the command line as well as through the `submodule.`_< name>_`.update` configuration are:

[](https://git-scm.com/docs/git-submodule#Documentation/git-submodule.txt-checkout)checkout

the commit recorded in the superproject will be checked out in the submodule on a detached HEAD.
If `--force` is specified, the submodule will be checked out (using `git` `checkout` `--force`), even if the commit specified in the index of the containing repository already matches the commit checked out in the submodule.

[](https://git-scm.com/docs/git-submodule#Documentation/git-submodule.txt-rebase)rebase

the current branch of the submodule will be rebased onto the commit recorded in the superproject.

[](https://git-scm.com/docs/git-submodule#Documentation/git-submodule.txt-merge)merge

the commit recorded in the superproject will be merged into the current branch in the submodule.
The following update procedures have additional limitations:

[](https://git-scm.com/docs/git-submodule#Documentation/git-submodule.txt-customcommand)custom command

mechanism for running arbitrary commands with the commit ID as an argument. Specifically, if the `submodule.`_< name>_`.update` configuration variable is set to `!custom` `command`, the object name of the commit recorded in the superproject for the submodule is appended to the `custom` `command` string and executed. Note that this mechanism is not supported in the `.gitmodules` file or on the command line.

[](https://git-scm.com/docs/git-submodule#Documentation/git-submodule.txt-none)none

the submodule is not updated. This update procedure is not allowed on the command line.
If the submodule is not yet initialized, and you just want to use the setting as stored in `.gitmodules`, you can automatically initialize the submodule with the `--init` option.
If `--recursive` is specified, this command will recurse into the registered submodules, and update any nested submodules within.
If `--ref-format` _< format>_ is specified, the ref storage format of newly cloned submodules will be set accordingly.
If `--filter` _< filter-spec>_ is specified, the given partial clone filter will be applied to the submodule. See [git-rev-list[1]](https://git-scm.com/docs/git-rev-list) for details on filter specifications.

[](https://git-scm.com/docs/git-submodule#Documentation/git-submodule.txt-set-branch-b--branchbranch--path)set-branch (-b|--branch) <branch> [--] <path>


[](https://git-scm.com/docs/git-submodule#Documentation/git-submodule.txt-set-branch-d--default--path)set-branch (-d|--default) [--] <path>

Sets the default remote tracking branch for the submodule. The `--branch` option allows the remote branch to be specified. The `--default` option removes the submodule.<name>.branch configuration key, which causes the tracking branch to default to the remote _HEAD_.

[](https://git-scm.com/docs/git-submodule#Documentation/git-submodule.txt-set-url--pathnewurl)set-url [--] <path> <newurl>

Sets the URL of the specified submodule to <newurl>. Then, it will automatically synchronize the submodule’s new remote URL configuration.

[](https://git-scm.com/docs/git-submodule#Documentation/git-submodule.txt-summary--cached--files-n--summary-limitncommit--path)summary [--cached|--files] [(-n|--summary-limit) <n>] [commit] [--] [<path>…​]

Show commit summary between the given commit (defaults to HEAD) and working tree/index. For a submodule in question, a series of commits in the submodule between the given super project commit and the index or working tree (switched by `--cached`) are shown. If the option `--files` is given, show the series of commits in the submodule between the index of the super project and the working tree of the submodule (this option doesn’t allow to use the `--cached` option or to provide an explicit commit).
Using the `--submodule=log` option with [git-diff[1]](https://git-scm.com/docs/git-diff) will provide that information too.

[](https://git-scm.com/docs/git-submodule#Documentation/git-submodule.txt-foreach--recursivecommand)foreach [--recursive] <command>

Evaluates an arbitrary shell command in each checked out submodule. The command has access to the variables $name, $sm_path, $displaypath, $sha1 and $toplevel: $name is the name of the relevant submodule section in `.gitmodules`, $sm_path is the path of the submodule as recorded in the immediate superproject, $displaypath contains the relative path from the current working directory to the submodules root directory, $sha1 is the commit as recorded in the immediate superproject, and $toplevel is the absolute path to the top-level of the immediate superproject. Note that to avoid conflicts with _$PATH_ on Windows, the _$path_ variable is now a deprecated synonym of _$sm_path_ variable. Any submodules defined in the superproject but not checked out are ignored by this command. Unless given `--quiet`, foreach prints the name of each submodule before evaluating the command. If `--recursive` is given, submodules are traversed recursively (i.e. the given shell command is evaluated in nested submodules as well). A non-zero return from the command in any submodule causes the processing to terminate. This can be overridden by adding _|| :_ to the end of the command.
As an example, the command below will show the path and currently checked out commit for each submodule:
```
git submodule foreach 'echo $sm_path `git rev-parse HEAD`'
```


[](https://git-scm.com/docs/git-submodule#Documentation/git-submodule.txt-sync--recursive--path)sync [--recursive] [--] [<path>…​]

Synchronizes submodules' remote URL configuration setting to the value specified in `.gitmodules`. It will only affect those submodules which already have a URL entry in .git/config (that is the case when they are initialized or freshly added). This is useful when submodule URLs change upstream and you need to update your local repositories accordingly.
`git` `submodule` `sync` synchronizes all submodules while `git` `submodule` `sync` `--` `A` synchronizes submodule "A" only.
If `--recursive` is specified, this command will recurse into the registered submodules, and sync any nested submodules within.

[](https://git-scm.com/docs/git-submodule#Documentation/git-submodule.txt-absorbgitdirs)absorbgitdirs

If a git directory of a submodule is inside the submodule, move the git directory of the submodule into its superproject’s `$GIT_DIR/modules` path and then connect the git directory and its working directory by setting the `core.worktree` and adding a .git file pointing to the git directory embedded in the superprojects git directory.
A repository that was cloned independently and later added as a submodule or old setups have the submodules git directory inside the submodule instead of embedded into the superprojects git directory.
This command is recursive by default.
##  [](https://git-scm.com/docs/git-submodule#_options)OPTIONS

[](https://git-scm.com/docs/git-submodule#Documentation/git-submodule.txt--q)-q


[](https://git-scm.com/docs/git-submodule#Documentation/git-submodule.txt---quiet)--quiet

Only print error messages.

[](https://git-scm.com/docs/git-submodule#Documentation/git-submodule.txt---progress)--progress

This option is only valid for add and update commands. Progress status is reported on the standard error stream by default when it is attached to a terminal, unless -q is specified. This flag forces progress status even if the standard error stream is not directed to a terminal.

[](https://git-scm.com/docs/git-submodule#Documentation/git-submodule.txt---all)--all

This option is only valid for the deinit command. Unregister all submodules in the working tree.

[](https://git-scm.com/docs/git-submodule#Documentation/git-submodule.txt--bbranch)-b <branch>


[](https://git-scm.com/docs/git-submodule#Documentation/git-submodule.txt---branchbranch)--branch <branch>

Branch of repository to add as submodule. The name of the branch is recorded as `submodule.`_< name>_`.branch` in `.gitmodules` for `update` `--remote`. A special value of `.` is used to indicate that the name of the branch in the submodule should be the same name as the current branch in the current repository. If the option is not specified, it defaults to the remote _HEAD_.

[](https://git-scm.com/docs/git-submodule#Documentation/git-submodule.txt--f)-f


[](https://git-scm.com/docs/git-submodule#Documentation/git-submodule.txt---force)--force

This option is only valid for add, deinit and update commands. When running add, allow adding an otherwise ignored submodule path. This option is also used to bypass a check that the submodule’s name is not already in use. By default, _git submodule add_ will fail if the proposed name (which is derived from the path) is already registered for another submodule in the repository. Using _--force_ allows the command to proceed by automatically generating a unique name by appending a number to the conflicting name (e.g., if a submodule named _child_ exists, it will try _child1_ , and so on). When running deinit the submodule working trees will be removed even if they contain local changes. When running update (only effective with the checkout procedure), throw away local changes in submodules when switching to a different commit; and always run a checkout operation in the submodule, even if the commit listed in the index of the containing repository matches the commit checked out in the submodule.

[](https://git-scm.com/docs/git-submodule#Documentation/git-submodule.txt---cached)--cached

This option is only valid for status and summary commands. These commands typically use the commit found in the submodule HEAD, but with this option, the commit stored in the index is used instead.

[](https://git-scm.com/docs/git-submodule#Documentation/git-submodule.txt---files)--files

This option is only valid for the summary command. This command compares the commit in the index with that in the submodule HEAD when this option is used.

[](https://git-scm.com/docs/git-submodule#Documentation/git-submodule.txt--n)-n


[](https://git-scm.com/docs/git-submodule#Documentation/git-submodule.txt---summary-limit)--summary-limit

This option is only valid for the summary command. Limit the summary size (number of commits shown in total). Giving 0 will disable the summary; a negative number means unlimited (the default). This limit only applies to modified submodules. The size is always limited to 1 for added/deleted/typechanged submodules.

[](https://git-scm.com/docs/git-submodule#Documentation/git-submodule.txt---remote)--remote

This option is only valid for the update command. Instead of using the superproject’s recorded SHA-1 to update the submodule, use the status of the submodule’s remote-tracking branch. The remote used is branch’s remote (`branch.`_< name>_`.remote`), defaulting to `origin`. The remote branch used defaults to the remote `HEAD`, but the branch name may be overridden by setting the `submodule.`_< name>_`.branch` option in either `.gitmodules` or `.git/config` (with `.git/config` taking precedence).
This works for any of the supported update procedures (`--checkout`, `--rebase`, etc.). The only change is the source of the target SHA-1. For example, `submodule` `update` `--remote` `--merge` will merge upstream submodule changes into the submodules, while `submodule` `update` `--merge` will merge superproject gitlink changes into the submodules.
In order to ensure a current tracking branch state, `update` `--remote` fetches the submodule’s remote repository before calculating the SHA-1. If you don’t want to fetch, you should use `submodule` `update` `--remote` `--no-fetch`.
Use this option to integrate changes from the upstream subproject with your submodule’s current HEAD. Alternatively, you can run `git` `pull` from the submodule, which is equivalent except for the remote branch name: `update` `--remote` uses the default upstream repository and `submodule.`_< name>_`.branch`, while `git` `pull` uses the submodule’s `branch.`_< name>_`.merge`. Prefer `submodule.`_< name>_`.branch` if you want to distribute the default upstream branch with the superproject and `branch.`_< name>_`.merge` if you want a more native feel while working in the submodule itself.

[](https://git-scm.com/docs/git-submodule#Documentation/git-submodule.txt--N)-N


[](https://git-scm.com/docs/git-submodule#Documentation/git-submodule.txt---no-fetch)--no-fetch

This option is only valid for the update command. Don’t fetch new objects from the remote site.

[](https://git-scm.com/docs/git-submodule#Documentation/git-submodule.txt---checkout)--checkout

This option is only valid for the update command. Checkout the commit recorded in the superproject on a detached HEAD in the submodule. This is the default behavior, the main use of this option is to override `submodule.$name.update` when set to a value other than `checkout`. If the key `submodule.$name.update` is either not explicitly set or set to `checkout`, this option is implicit.

[](https://git-scm.com/docs/git-submodule#Documentation/git-submodule.txt---merge)--merge

This option is only valid for the update command. Merge the commit recorded in the superproject into the current branch of the submodule. If this option is given, the submodule’s HEAD will not be detached. If a merge failure prevents this process, you will have to resolve the resulting conflicts within the submodule with the usual conflict resolution tools. If the key `submodule.$name.update` is set to `merge`, this option is implicit.

[](https://git-scm.com/docs/git-submodule#Documentation/git-submodule.txt---rebase)--rebase

This option is only valid for the update command. Rebase the current branch onto the commit recorded in the superproject. If this option is given, the submodule’s HEAD will not be detached. If a merge failure prevents this process, you will have to resolve these failures with [git-rebase[1]](https://git-scm.com/docs/git-rebase). If the key `submodule.$name.update` is set to `rebase`, this option is implicit.

[](https://git-scm.com/docs/git-submodule#Documentation/git-submodule.txt---init)--init

This option is only valid for the update command. Initialize all submodules for which "git submodule init" has not been called so far before updating.

[](https://git-scm.com/docs/git-submodule#Documentation/git-submodule.txt---name)--name

This option is only valid for the add command. It sets the submodule’s name to the given string instead of defaulting to its path. The name must be valid as a directory name and may not end with a _/_.

[](https://git-scm.com/docs/git-submodule#Documentation/git-submodule.txt---referencerepository)--reference <repository>

This option is only valid for add and update commands. These commands sometimes need to clone a remote repository. In this case, this option will be passed to the [git-clone[1]](https://git-scm.com/docs/git-clone) command.
**NOTE** : Do **not** use this option unless you have read the note for [git-clone[1]](https://git-scm.com/docs/git-clone)'s `--reference`, `--shared`, and `--dissociate` options carefully.

[](https://git-scm.com/docs/git-submodule#Documentation/git-submodule.txt---dissociate)--dissociate

This option is only valid for add and update commands. These commands sometimes need to clone a remote repository. In this case, this option will be passed to the [git-clone[1]](https://git-scm.com/docs/git-clone) command.
**NOTE** : see the NOTE for the `--reference` option.

[](https://git-scm.com/docs/git-submodule#Documentation/git-submodule.txt---recursive)--recursive

This option is only valid for foreach, update, status and sync commands. Traverse submodules recursively. The operation is performed not only in the submodules of the current repo, but also in any nested submodules inside those submodules (and so on).

[](https://git-scm.com/docs/git-submodule#Documentation/git-submodule.txt---depth)--depth

This option is valid for add and update commands. Create a _shallow_ clone with a history truncated to the specified number of revisions. See [git-clone[1]](https://git-scm.com/docs/git-clone)

[](https://git-scm.com/docs/git-submodule#Documentation/git-submodule.txt---recommend-shallow)--recommend-shallow


[](https://git-scm.com/docs/git-submodule#Documentation/git-submodule.txt---no-recommend-shallow)--no-recommend-shallow

This option is only valid for the update command. The initial clone of a submodule will use the recommended `submodule.`_< name>_`.shallow` as provided by the `.gitmodules` file by default. To ignore the suggestions use `--no-recommend-shallow`.

[](https://git-scm.com/docs/git-submodule#Documentation/git-submodule.txt--jn)-j <n>


[](https://git-scm.com/docs/git-submodule#Documentation/git-submodule.txt---jobsn)--jobs <n>

This option is only valid for the update command. Clone new submodules in parallel with as many jobs. Defaults to the `submodule.fetchJobs` option.

[](https://git-scm.com/docs/git-submodule#Documentation/git-submodule.txt---single-branch)--single-branch


[](https://git-scm.com/docs/git-submodule#Documentation/git-submodule.txt---no-single-branch)--no-single-branch

This option is only valid for the update command. Clone only one branch during update: HEAD or one specified by --branch.

[](https://git-scm.com/docs/git-submodule#Documentation/git-submodule.txt-path)<path>…​

Paths to submodule(s). When specified this will restrict the command to only operate on the submodules found at the specified paths. (This argument is required with add).
##  [](https://git-scm.com/docs/git-submodule#_files)FILES
When initializing submodules, a `.gitmodules` file in the top-level directory of the containing repository is used to find the url of each submodule. This file should be formatted in the same way as `$GIT_DIR/config`. The key to each submodule url is "submodule.$name.url". See [gitmodules[5]](https://git-scm.com/docs/gitmodules) for details.
##  [](https://git-scm.com/docs/git-submodule#_see_also)SEE ALSO
[gitsubmodules[7]](https://git-scm.com/docs/gitsubmodules), [gitmodules[5]](https://git-scm.com/docs/gitmodules).
##  [](https://git-scm.com/docs/git-submodule#_git)GIT
Part of the [git[1]](https://git-scm.com/docs/git) suite
### submodule
[About this site](https://git-scm.com/site)
Patches, suggestions, and comments are welcome.
Git is a member of [Software Freedom Conservancy](https://git-scm.com/sfc)
